pub enum HeaderImagePosition {
Left,
Center,
Right,
}Expand description
The HeaderImagePosition enum defines the image position in a header or footer.
Used with the
Worksheet::set_header_image() and
Worksheet::set_footer_image()
methods.
Variants
Left
The image is positioned in the left section of the header/footer.
Center
The image is positioned in the center section of the header/footer.
Right
The image is positioned in the right section of the header/footer.